#!/bin/sh

# $Id: install.sh,v 2.2 2003/06/18 11:13:06 mcourtoi Exp $
# $Name: v7_3-8 $

# choix ksh / bash

if [ -x /bin/bash ]; then
   SHELL_INSTALL_ASTER=/bin/bash
elif [ -x /bin/ksh ]; then
   SHELL_INSTALL_ASTER=/bin/ksh
elif [ -x /bin/zsh ]; then
   SHELL_INSTALL_ASTER=/bin/zsh
else
   echo "Neither bash, ksh or zsh found. STOP !"
   exit
fi

if [ $# -ne 0 ] && [ $1 = "-debug" ]; then
   SHELL_INSTALL_ASTER="$SHELL_INSTALL_ASTER -xv"
fi

echo "Start scripts using $SHELL_INSTALL_ASTER"

export SHELL_INSTALL_ASTER
$SHELL_INSTALL_ASTER `dirname $0`/UTILS/main.sh | tee install.log
