# The SHELL is choosen by install.sh

# $Id: main.sh,v 1.8 2004/05/10 13:09:05 mcourtoi Exp $
# $Name: v7_3-8 $

######################################################################
#
# Installation script for Code_Aster and its tools
#
######################################################################

dirhome=`dirname $0`
if [ $dirhome = "." ]; then
   dirhome=`pwd`
fi

iret=-1

######################################################################
#
# variables to adjust with the version of the products you have
#
vaster=STA7.3
vastk=1.1.0

# to create a development version based on this STA
pseudo_vers=STA7.3

tcl_v=8.4
python_v=2.2
numeric_v=20.3
gnuplotpy_v=1.5
pmw_v=0.8.5
gnuplot_v=3.7.1

med_v=2.1.5
hdf_v=5.1.4.4
metis_v=metis-edf-3.1
homard_v=6.2
gibi_v=2000

######################################################################
#
# Check for Code_Aster installation script
#

if [ -f $dirhome/main_aster.sh ]; then
# source (SRC=1) or binary (SRC=0, BIN=os_type) package
   SRC=1
   BIN=all
   iret=0
   . $dirhome/main_aster.sh
elif [ -f $dirhome/main_astk.sh ]; then
# ASTK
   iret=0
   . $dirhome/main_astk.sh
fi

if [ $iret -ne 0 ]; then
	echo "Nothing to install !"
	exit 8
fi

exit 0
